@@ -342,7 +342,6 @@ bool KgpgEditor::slotFileSaveAs()
 	if(!url.isEmpty()) {
 		const QString selectedEncoding = saveResult.encoding;
 		if (url.isLocalFile()) {
-			QString filn = url.path();
 			QFile f(url.path());
 			if (f.exists()) {
 				const QString message = i18n("Overwrite existing file %1?", url.fileName());
@@ -434,7 +433,9 @@ void KgpgEditor::slotFindPrev()
     long newopt = oldopt ^ KFind::FindBackwards;
     m_find->setOptions(newopt);
     slotFindText();
-    m_find->setOptions(oldopt);
+    if (m_find) {
+        m_find->setOptions(oldopt);
+    }
 }
 
 void KgpgEditor::slotFindText()
