@@ -66,6 +66,7 @@
 #include <KActionCollection>
 #include <KContacts/AddresseeList>
 // #include <KContacts/Key> TODO
+#include <kwidgetsaddons_version.h>
 #include <KIO/Global>
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/OpenUrlJob>
@@ -141,7 +142,7 @@ KeysManager::KeysManager(QWidget *parent)
 	goToDefaultKey = actionCollection()->addAction(QLatin1String("go_default_key"), this, &KeysManager::slotGotoDefaultKey);
 	goToDefaultKey->setIcon(QIcon::fromTheme( QLatin1String( "go-home" )));
 	goToDefaultKey->setText(i18n("&Go to Default Key"));
-	actionCollection()->setDefaultShortcut(goToDefaultKey, QKeySequence(Qt::CTRL + Qt::Key_Home));
+	actionCollection()->setDefaultShortcut(goToDefaultKey, QKeySequence(Qt::CTRL | Qt::Key_Home));
 
 	s_kgpgEditor = new KgpgEditor(this, imodel, Qt::Dialog);
 	s_kgpgEditor->setAttribute(Qt::WA_DeleteOnClose, false);
@@ -183,7 +184,7 @@ KeysManager::KeysManager(QWidget *parent)
 	editKey = actionCollection()->addAction(QLatin1String("key_edit"), this, &KeysManager::slotedit);
 	editKey->setIcon(QIcon::fromTheme( QLatin1String( "utilities-terminal" )));
 	editKey->setText(i18n("Edit Key in &Terminal"));
-	actionCollection()->setDefaultShortcut(editKey, QKeySequence(Qt::ALT + Qt::Key_Return));
+	actionCollection()->setDefaultShortcut(editKey, QKeySequence(Qt::ALT | Qt::Key_Return));
 
 	QAction *generateKey = actionCollection()->addAction(QLatin1String("key_gener"), this, &KeysManager::slotGenerateKey);
 	generateKey->setIcon(QIcon::fromTheme( QLatin1String( "key-generate-pair" )));
@@ -421,8 +422,13 @@ KeysManager::KeysManager(QWidget *parent)
 	KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig().data(), "KeyView");
 	iview->restoreLayout(cg);
 
+#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 78, 0)
 	connect(photoProps, QOverload<int>::of(&KSelectAction::triggered), this, &KeysManager::slotSetPhotoSize);
 	connect(trustProps, QOverload<int>::of(&KSelectAction::triggered), this, &KeysManager::slotSetTrustFilter);
+#else
+	connect(photoProps, &KSelectAction::indexTriggered, this, &KeysManager::slotSetPhotoSize);
+	connect(trustProps, &KSelectAction::indexTriggered, this, &KeysManager::slotSetTrustFilter);
+#endif
 
 	QLabel *searchLabel = new QLabel(i18n("Search:"), this);
 	m_listviewsearch = new QLineEdit(this);
@@ -1955,8 +1961,6 @@ void KeysManager::signLoop(const bool localsign, const int checklevel)
 	Q_ASSERT(keyCount < signList.count());
 
 	KGpgSignableNode *nd = signList.at(keyCount);
-	QString uid;
-	QString keyid;
 	const KGpgSignTransactionHelper::carefulCheck cc = static_cast<KGpgSignTransactionHelper::carefulCheck>(checklevel);
 	KGpgTransaction *sta;
 
